@@ -32,7 +32,7 @@ TestFriends::TestFriends()
 
 void TestFriends::initTestCase()
 {
-    authenticate();
+    authenticate(Vkontakte::AppPermissions::NoPermissions);
 }
 
 void TestFriends::testFriendListJob()
@@ -46,4 +46,3 @@ void TestFriends::testFriendListJob()
 }
 
 QTEST_KDEMAIN(TestFriends, GUI)
-#include "test_friends.h"
